@@ -1,4 +1,5 @@
 use crate::checkers::checker_result::CheckResult;
+use crate::cli_pretty_printing::human_checker_check;
 use crate::config::get_config;
 use crate::timer;
 use text_io::read;
@@ -13,16 +14,11 @@ pub fn human_checker(input: &CheckResult) -> bool {
     // wait instead of get so it waits for config being set
     let config = get_config();
     // We still call human checker, just if config is false we return True
-    if !config.human_checker_on {
+    if !config.human_checker_on || config.api_mode {
         return true;
     }
+    human_checker_check(&input.description, &input.text);
 
-    let output_string = format!(
-        "I think the plaintext is a {}.\nPossible plaintext: '{}' (y/N): ",
-        input.description, input.text
-    );
-    // print output_string and ask user to input yes or no
-    println!("{}", output_string);
     let reply: String = read!("{}\n");
     let result = reply.to_ascii_lowercase().starts_with('y');
     if !result {
