@@ -18,26 +18,27 @@ pub struct Decoder<Type> {
     /// you would use the tag "base64" or "base".
     /// You can also add tags like "online" to filter decoders that are online.
     pub tags: Vec<&'static str>,
-    /// We get expectedRuntime this by bench marking the code
-    pub expected_runtime: f32,
     /// We get popularity by eye-balling it or using the API's data
     pub popularity: f32,
-    /// Expected success is calculated during cracking
-    /// Generally this can be ignored and set to 1.0
-    pub expected_success: f32,
-    /// failure_runtime is the absolute worst case
-    /// Expected is how long we expect, if it fails completely
-    /// This is how long it'll take to fail.
-    pub failure_runtime: f32,
-    /// normalised_entropy is the range of entropy for this
-    /// So base64's normalised entropy might be between 2.5 and 3
-    /// This allows us to decide whether it's worth decoding
-    /// If current text has entropy 9, it's unlikey to be base64
-    pub normalised_entropy: Vec<f32>,
     /// we don't use the Type, so we use PhantomData to mark it!
     pub phantom: std::marker::PhantomData<Type>,
 }
 
+/// The default implementation for a decoder
+pub struct DefaultDecoder;
+impl Default for Decoder<DefaultDecoder> {
+    fn default() -> Decoder<DefaultDecoder> {
+        Decoder {
+            name: "Default decoder",
+            description: "N/A",
+            link: "N/A",
+            tags: vec!["N/A"],
+            popularity: 0.0,
+            phantom: std::marker::PhantomData,
+        }
+    }
+}
+
 /// All decoders will share the same Crack trait
 /// Which let's us put them into a vector and iterate over them,
 /// Running `.crack()` on each of them.
@@ -49,6 +50,10 @@ pub trait Crack {
         Self: Sized;
     /// Crack is the function that actually does the decoding
     fn crack(&self, text: &str, checker: &CheckerTypes) -> CrackResult;
+    /// Get all tags for the current decoder
+    fn get_tags(&self) -> &Vec<&str>;
+    /// Get the nam of the current decoder
+    fn get_name(&self) -> &str;
 }
 
 /// Returns a boolean of True if the string is successfully changed
